import * as i0 from '@angular/core';
import { Pipe, Component, ChangeDetectionStrategy, Input, HostBinding, Injectable, inject, signal, EventEmitter, Output, DestroyRef, NgModule } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialog, MatDialogModule } from '@angular/material/dialog';
import * as i1 from '@angular/material/menu';
import { MatMenuModule } from '@angular/material/menu';
import { RxIf } from '@rx-angular/template/if';
import { RxFor } from '@rx-angular/template/for';
import { NgClass, NgOptimizedImage } from '@angular/common';
import { BehaviorSubject, tap, filter, map, exhaustMap, catchError, EMPTY } from 'rxjs';
import { getWallets } from '@wallet-standard/core';
import { remove, uniqBy, has as has$1 } from 'lodash-es';
import { RxPush } from '@rx-angular/template/push';
import has from 'lodash-es/has';
import BigNumber from 'bignumber.js';
import * as i2 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import { ComponentStore } from '@ngrx/component-store';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';

// https://github.com/MystenLabs/sui/blob/481c29edd25da4460d35eeccfe894780a9a79b06/sdk/wallet-standard/src/chains.ts#L14
// Copyright (c) Mysten Labs, Inc.
// SPDX-License-Identifier: Apache-2.0
/** Sui Devnet */
const SUI_DEVNET_CHAIN = 'sui:devnet';
/** Sui Testnet */
const SUI_TESTNET_CHAIN = 'sui:testnet';
/** Sui Localnet */
const SUI_LOCALNET_CHAIN = 'sui:localnet';
/** Sui Mainnet */
const SUI_MAINNET_CHAIN = 'sui:mainnet';
const SUI_CHAINS = [
    SUI_DEVNET_CHAIN,
    SUI_TESTNET_CHAIN,
    SUI_LOCALNET_CHAIN,
    SUI_MAINNET_CHAIN,
];

var WalletIconEnum;
(function (WalletIconEnum) {
    WalletIconEnum["Sui"] = "Sui Wallet";
    WalletIconEnum["Suiet"] = "Suiet";
    WalletIconEnum["Elli"] = "Elli";
    WalletIconEnum["Ethos"] = "Ethos Wallet";
    WalletIconEnum["FrontierWallet"] = "Frontier Wallet";
    WalletIconEnum["Frontier"] = "Frontier";
    WalletIconEnum["Glass"] = "GlassWallet";
    WalletIconEnum["Martian"] = "Martian Sui Wallet";
    WalletIconEnum["Morphis"] = "Morphis Wallet";
    WalletIconEnum["Nightly"] = "Nightly";
    WalletIconEnum["OneKey"] = "OneKey Wallet";
    WalletIconEnum["SenSui"] = "SenSui Wallet";
    WalletIconEnum["Spacecy"] = "Spacecy Sui Wallet";
    WalletIconEnum["Surf"] = "Surf Wallet";
})(WalletIconEnum || (WalletIconEnum = {}));

/**
 * The Wallet Icon Pipe.
 */
class WalletIconPipe {
    /**
     * Transforms a wallet icon enum value into its corresponding string representation.
     *
     * @param {string | undefined} value - The wallet icon enum value to be transformed.
     * @return {string} The string representation of the wallet icon.
     */
    transform(value) {
        switch (value) {
            case WalletIconEnum.Sui:
                return 'sui-angular/sui.svg';
            case WalletIconEnum.Suiet:
                return 'sui-angular/suiet.svg';
            case WalletIconEnum.Elli:
                return 'sui-angular/elli.svg';
            case WalletIconEnum.Ethos:
                return 'sui-angular/ethos.svg';
            case WalletIconEnum.FrontierWallet:
            case WalletIconEnum.Frontier:
                return 'sui-angular/frontier.svg';
            case WalletIconEnum.Glass:
                return 'sui-angular/glass.svg';
            case WalletIconEnum.Martian:
                return 'sui-angular/martian.svg';
            case WalletIconEnum.Morphis:
                return 'sui-angular/morphis.svg';
            case WalletIconEnum.Nightly:
                return 'sui-angular/nightly.svg';
            case WalletIconEnum.OneKey:
                return 'sui-angular/onekey.svg';
            case WalletIconEnum.SenSui:
                return 'sui-angular/sensui.svg';
            case WalletIconEnum.Spacecy:
                return 'sui-angular/spacecy.jpg';
            case WalletIconEnum.Surf:
                return 'sui-angular/surf.jpg';
            default:
                return 'sui-angular/sui.svg';
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: WalletIconPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "16.2.10", ngImport: i0, type: WalletIconPipe, isStandalone: true, name: "walletIcon" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: WalletIconPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'walletIcon',
                    standalone: true,
                }]
        }] });

/**
 * The Button Component
 */
class ButtonComponent {
    constructor() {
        this.type = 'primary';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: ButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.10", type: ButtonComponent, isStandalone: true, selector: "sa-button", inputs: { text: "text", type: "type", disabled: "disabled" }, host: { properties: { "class.disabled": "this.disabled" } }, ngImport: i0, template: "<a class=\"btn btn-shadow\" [ngClass]=\"'btn-' + type\">\n  {{ text }}\n</a>\n", styles: [".btn{-ms-transition:all .2s;-webkit-transition:all .2s;align-items:center;border-radius:8px;border:1px solid transparent;cursor:pointer;display:inline-flex;font-size:16px;font-weight:500;justify-content:center;line-height:1.6;overflow:hidden;padding:12px 25px;position:relative;text-align:center;text-decoration:none;text-transform:capitalize;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;-webkit-user-select:none;user-select:none;vertical-align:middle;width:100%;z-index:1}.btn:after{content:\"\";position:absolute;background-color:inherit;height:100%;width:7px;left:-12px;z-index:1;top:50%;transform:translateY(-50%)}.btn:hover:after{transition:all .5s;border-right:7px solid #fff;opacity:0;width:100%}@media (prefers-reduced-motion: reduce){.btn{transition:none}}.btn:disabled{pointer-events:none;opacity:.65}.btn-primary{--button-background: var(--sa-color-button-primary-background, rgba(2, 163, 254, 1));--button-background-active: var(--sa-color-button-primary-background, rgba(2, 163, 254, 1));--button-box-shadow: var(--sa-color-button-primary-box-shadow, rgba(2, 163, 254, .2));--button-border-active: var(--sa-color-button-primary-active-border, rgba(27, 172, 254, 1));--button-active-box-shadow: var( --sa-color-button-primary-active-box-shadow, rgba(2, 139, 216, .5) );color:#fff;background-color:var(--button-background);border-color:var(--button-background)}.btn-primary:hover{background-color:var(--button-background-active);border-color:var(--button-border-active);color:#fff}.btn-primary:focus{background-color:var(--button-background-active);border-color:var(--button-border-active);box-shadow:0 0 0 0 var(--button-active-box-shadow)}.btn-primary.active:focus{box-shadow:0 0 0 0 var(--button-active-box-shadow)}.btn-primary:disabled,.btn-primary.disabled{background-color:var(--button-background);border-color:var(--button-background)}.btn-primary.btn-shadow{box-shadow:0 4px 10px var(--button-box-shadow)}.btn-primary:after{background-color:#090915}.btn-secondary{--button-background: var(--sa-color-button-secondary-background, rgba(251, 186, 36, 1));--button-background-active: var(--sa-color-button-secondary-background, rgba(251, 186, 36, 1));--button-box-shadow: var(--sa-color-button-secondary-box-shadow, rgba(251, 186, 36, .2));--button-border-active: var(--sa-color-button-secondary-active-border, rgba(240, 174, 4));--button-active-box-shadow: var(--sa-color-button-secondary-active-box-shadow, rgba(251, 186, 36, .5));color:#fff;background-color:var(--button-background);border-color:var(--button-background)}.btn-secondary:hover{background-color:var(--button-background-active);border-color:var(--button-border-active);color:#fff}.btn-secondary:focus{background-color:var(--button-background-active);border-color:var(--button-border-active);box-shadow:0 0 0 0 var(--button-active-box-shadow)}.btn-secondary.active:focus{box-shadow:0 0 0 0 var(--button-active-box-shadow)}.btn-secondary:disabled,.btn-secondary.disabled{background-color:var(--button-background);border-color:var(--button-background)}.btn-secondary.btn-shadow{box-shadow:0 4px 10px var(--button-box-shadow)}.btn-secondary:after{background-color:#090915}:host.disabled .btn-primary,:host.disabled .btn-secondary{--button-background: var(--sa-color-disabled, rgba(97, 97, 97, 1));--button-box-shadow: var(--sa-color-disabled, rgba(97, 97, 97, 1));pointer-events:none}\n"], dependencies: [{ kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: ButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sa-button', changeDetection: ChangeDetectionStrategy.OnPush, imports: [NgClass], standalone: true, template: "<a class=\"btn btn-shadow\" [ngClass]=\"'btn-' + type\">\n  {{ text }}\n</a>\n", styles: [".btn{-ms-transition:all .2s;-webkit-transition:all .2s;align-items:center;border-radius:8px;border:1px solid transparent;cursor:pointer;display:inline-flex;font-size:16px;font-weight:500;justify-content:center;line-height:1.6;overflow:hidden;padding:12px 25px;position:relative;text-align:center;text-decoration:none;text-transform:capitalize;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;-webkit-user-select:none;user-select:none;vertical-align:middle;width:100%;z-index:1}.btn:after{content:\"\";position:absolute;background-color:inherit;height:100%;width:7px;left:-12px;z-index:1;top:50%;transform:translateY(-50%)}.btn:hover:after{transition:all .5s;border-right:7px solid #fff;opacity:0;width:100%}@media (prefers-reduced-motion: reduce){.btn{transition:none}}.btn:disabled{pointer-events:none;opacity:.65}.btn-primary{--button-background: var(--sa-color-button-primary-background, rgba(2, 163, 254, 1));--button-background-active: var(--sa-color-button-primary-background, rgba(2, 163, 254, 1));--button-box-shadow: var(--sa-color-button-primary-box-shadow, rgba(2, 163, 254, .2));--button-border-active: var(--sa-color-button-primary-active-border, rgba(27, 172, 254, 1));--button-active-box-shadow: var( --sa-color-button-primary-active-box-shadow, rgba(2, 139, 216, .5) );color:#fff;background-color:var(--button-background);border-color:var(--button-background)}.btn-primary:hover{background-color:var(--button-background-active);border-color:var(--button-border-active);color:#fff}.btn-primary:focus{background-color:var(--button-background-active);border-color:var(--button-border-active);box-shadow:0 0 0 0 var(--button-active-box-shadow)}.btn-primary.active:focus{box-shadow:0 0 0 0 var(--button-active-box-shadow)}.btn-primary:disabled,.btn-primary.disabled{background-color:var(--button-background);border-color:var(--button-background)}.btn-primary.btn-shadow{box-shadow:0 4px 10px var(--button-box-shadow)}.btn-primary:after{background-color:#090915}.btn-secondary{--button-background: var(--sa-color-button-secondary-background, rgba(251, 186, 36, 1));--button-background-active: var(--sa-color-button-secondary-background, rgba(251, 186, 36, 1));--button-box-shadow: var(--sa-color-button-secondary-box-shadow, rgba(251, 186, 36, .2));--button-border-active: var(--sa-color-button-secondary-active-border, rgba(240, 174, 4));--button-active-box-shadow: var(--sa-color-button-secondary-active-box-shadow, rgba(251, 186, 36, .5));color:#fff;background-color:var(--button-background);border-color:var(--button-background)}.btn-secondary:hover{background-color:var(--button-background-active);border-color:var(--button-border-active);color:#fff}.btn-secondary:focus{background-color:var(--button-background-active);border-color:var(--button-border-active);box-shadow:0 0 0 0 var(--button-active-box-shadow)}.btn-secondary.active:focus{box-shadow:0 0 0 0 var(--button-active-box-shadow)}.btn-secondary:disabled,.btn-secondary.disabled{background-color:var(--button-background);border-color:var(--button-background)}.btn-secondary.btn-shadow{box-shadow:0 4px 10px var(--button-box-shadow)}.btn-secondary:after{background-color:#090915}:host.disabled .btn-primary,:host.disabled .btn-secondary{--button-background: var(--sa-color-disabled, rgba(97, 97, 97, 1));--button-box-shadow: var(--sa-color-disabled, rgba(97, 97, 97, 1));pointer-events:none}\n"] }]
        }], propDecorators: { text: [{
                type: Input
            }], type: [{
                type: Input
            }], disabled: [{
                type: HostBinding,
                args: ['class.disabled']
            }, {
                type: Input
            }] } });

/**
 * The Text Card Component.
 */
class TextCardComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: TextCardComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.10", type: TextCardComponent, isStandalone: true, selector: "text-card", inputs: { header: "header", description: "description" }, ngImport: i0, template: "<div class=\"text-primary\">\n  <div class=\"text-14 mb-4 font-bold\">{{ header }}</div>\n  <div class=\"mb-4 text-14 text-tertiary\">{{ description }}</div>\n</div>\n", styles: [""], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: TextCardComponent, decorators: [{
            type: Component,
            args: [{ selector: 'text-card', standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"text-primary\">\n  <div class=\"text-14 mb-4 font-bold\">{{ header }}</div>\n  <div class=\"mb-4 text-14 text-tertiary\">{{ description }}</div>\n</div>\n" }]
        }], propDecorators: { header: [{
                type: Input
            }], description: [{
                type: Input
            }] } });

/**
 * The Text Header Component.
 */
class TextHeaderComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: TextHeaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.10", type: TextHeaderComponent, isStandalone: true, selector: "text-header", inputs: { text: "text" }, ngImport: i0, template: "<div class=\"text-primary text-18 font-bold text-center\">{{ text }}</div>\n", styles: [""], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: TextHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'text-header', standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"text-primary text-18 font-bold text-center\">{{ text }}</div>\n" }]
        }], propDecorators: { text: [{
                type: Input
            }] } });

/**
 * The Wallet Button Component.
 */
class WalletButtonComponent {
    get _icon() {
        return this.icon === 'GlassWallet' ? 'Glass Wallet' : this.icon;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: WalletButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.10", type: WalletButtonComponent, isStandalone: true, selector: "wallet-button", inputs: { icon: "icon" }, ngImport: i0, template: "<div class=\"mt-24 flex items-center cursor-pointer\">\n  <img [src]=\"icon | walletIcon\" width=\"24\" height=\"24\" />\n  <div class=\"text-primary font-bold text-16 mx-16\">{{ _icon }}</div>\n</div>\n", styles: [""], dependencies: [{ kind: "pipe", type: WalletIconPipe, name: "walletIcon" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: WalletButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'wallet-button', changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [WalletIconPipe, NgOptimizedImage], template: "<div class=\"mt-24 flex items-center cursor-pointer\">\n  <img [src]=\"icon | walletIcon\" width=\"24\" height=\"24\" />\n  <div class=\"text-primary font-bold text-16 mx-16\">{{ _icon }}</div>\n</div>\n" }]
        }], propDecorators: { icon: [{
                type: Input
            }] } });

function isNonEmptyArray(value) {
    return Array.isArray(value) && value.length > 0;
}
function isStandardWalletAdapterCompatibleWallet(wallet) {
    return ("standard:connect" in wallet.features &&
        "standard:events" in wallet.features &&
        "sui:signAndExecuteTransactionBlock" in wallet.features);
}

class WalletStandardService {
    getInitStandardWalletAdapters() {
        return this.wallets?.get() ?? [];
    }
    constructor() {
        this.availableWalletAdapters$ = new BehaviorSubject([]);
        this.wallets = getWallets();
        this.clearListeners = this.wallets.on('register', (...newAdapters) => {
            const initWalletAdapters = this.getInitStandardWalletAdapters();
            let allAdapters = [...initWalletAdapters];
            const oneKeyWallet = remove(allAdapters, (item) => item._name === 'OneKey Wallet');
            allAdapters.push(...oneKeyWallet);
            allAdapters = uniqBy(allAdapters, 'name');
            newAdapters
                .filter(isStandardWalletAdapterCompatibleWallet)
                .filter((newAdapter) => !allAdapters.find((existAdapter) => existAdapter.name === newAdapter.name))
                .forEach((newAdapter) => {
                allAdapters.push(newAdapter);
            });
            this.availableWalletAdapters$.next(allAdapters);
        });
    }
    ngOnDestroy() {
        this.clearListeners();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: WalletStandardService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: WalletStandardService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: WalletStandardService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return []; } });

/**
 * Component for Connect Wallet Modal
 */
class ConnectWalletComponent {
    constructor() {
        this.dialogRef = inject(MatDialogRef);
        this.walletStandardService = inject(WalletStandardService);
        this.adapters = this.walletStandardService.availableWalletAdapters$;
        this.data = inject(MAT_DIALOG_DATA);
        this.error = signal('');
        this.isConnecting = signal('');
        this.sui = WalletIconEnum.Sui;
    }
    /**
     * Initiates the process of connecting a wallet using the provided wallet adapter.
     *
     * @public
     * @function
     * @param {StandardWalletAdapter} adapter - The wallet adapter to use for connecting.
     * @return {void}
     */
    connectWallet(adapter) {
        this.error.set('');
        if (adapter && has(adapter?.features, 'standard:connect')) {
            this.isConnecting.set(adapter.name);
            const feature = adapter.features['standard:connect'];
            feature
                .connect()
                .then(() => {
                this.handleConnect(adapter);
            })
                .catch((error) => {
                console.log(error, 'error');
                this.error.set(error.message ?? error.data ?? error.toString());
            });
        }
    }
    /**
     * Handles the connection of a wallet adapter and returns the account details for the specified network.
     *
     * This method is responsible for handling the connection of a wallet adapter and
     * searching for the account associated with the specified network. If an account is found,
     * it closes the dialog with the account information. Otherwise, it sets an error message
     * indicating the need to switch to the specified network and reload the browser.
     *
     * @param {StandardWalletAdapter} adapter - The wallet adapter to connect.
     * @returns {void} - This method does not return a value.
     */
    handleConnect(adapter) {
        let account;
        if (this.data?.network === SUI_MAINNET_CHAIN &&
            adapter.name === 'Frontier Wallet!') {
            account = adapter.accounts.find((account) => account.chains.includes('sui'));
        }
        else {
            account =
                this.data?.network &&
                    adapter.accounts.find((account) => account.chains.includes(this.data?.network));
        }
        if (account) {
            this.dialogRef.close({
                account: account.address,
                name: adapter.name,
            });
        }
        else {
            this.error.set(`You must switch to ${this.data.network} and reload the browser`);
        }
    }
    /**
     * Initiates the process of registering a wallet using the specified method.
     *
     * @public
     * @function
     * @return {void}
     */
    registerWallet() {
        /**
         * Sets the connecting state to indicate registration is in progress.
         *
         * @param {string} connectingMethod - The method being used for wallet registration.
         * @returns {void}
         */
        this.isConnecting.set(this.sui);
    }
    /**
     * Opens a new browser window to the SUI Wallet extension download page.
     *
     * This method opens a new browser window to the Chrome Web Store page for
     * the SUI Wallet extension, allowing users to download and install it.
     *
     * @returns {void} - This method does not return a value.
     */
    connectSui() {
        window.open('https://chrome.google.com/webstore/detail/sui-wallet/opcgpfmipidbgpenhmajoajpbobppdil', '_blank');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: ConnectWalletComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.10", type: ConnectWalletComponent, isStandalone: true, selector: "connect-wallet", ngImport: i0, template: "<div class=\"flex h-full\">\n  <div class=\"p-20 w-240 overflow-y-auto\">\n    <text-header [text]=\"data.connectWalletText\"></text-header>\n    <ng-container *rxIf=\"adapters | push; else dummyAdapter\">\n      <wallet-button\n        *rxFor=\"let adapter of adapters | push\"\n        [icon]=\"adapter.name\"\n        (click)=\"connectWallet(adapter)\"\n      ></wallet-button>\n    </ng-container>\n\n    <ng-template #dummyAdapter>\n      <wallet-button [icon]=\"sui\" (click)=\"registerWallet()\"></wallet-button>\n    </ng-template>\n  </div>\n  <div class=\"description flex-1 p-20 flex flex-col items-center justify-center\">\n    <ng-container *rxIf=\"!isConnecting(); else connecting\">\n      <text-header [text]=\"data.whatIsWalletText\"></text-header>\n\n      <div class=\"flex justify-center flex-1 flex-col\">\n        <text-card\n          class=\"mt-16\"\n          [header]=\"data.easyLoginHeaderText\"\n          [description]=\"data.easyLoginDescriptionText\"\n        ></text-card>\n        <text-card\n          class=\"mt-16\"\n          [header]=\"data.storeHeaderText\"\n          [description]=\"data.storeDescriptionText\"\n        ></text-card>\n      </div>\n    </ng-container>\n\n    <ng-template #connecting>\n      <div class=\"flex flex-col items-center\" *rxIf=\"(adapters | push).length; else registerWalletTmp\">\n        <img [src]=\"isConnecting() | walletIcon\" width=\"72px\"/>\n        <div class=\"text-20 text-primary mt-12\">{{ data.openingText }} {{ isConnecting() }}</div>\n        <div *rxIf=\"!error(); else errorTmp\" class=\"text-tertiary text-13\">\n          {{ data.confirmConnectText }}\n        </div>\n        <ng-template #errorTmp>\n          <div class=\"text-error text-13 text-center\">{{ error() }}</div>\n        </ng-template>\n      </div>\n    </ng-template>\n\n    <ng-template #registerWalletTmp>\n      <text-header [text]=\"data.getStartedSuiText\"></text-header>\n\n      <div class=\"flex justify-center flex-1 flex-col\">\n        <text-card\n          [header]=\"data.installExtensionHeaderText\"\n          [description]=\"data.installExtensionDescriptionText\"\n        ></text-card>\n        <text-card\n          class=\"mt-16\"\n          [header]=\"data.createOrImportHeaderText\"\n          [description]=\"data.createOrImportDescriptionText\"\n        ></text-card>\n        <text-card\n          class=\"mt-16\"\n          [header]=\"data.refreshBrowserHeaderText\"\n          [description]=\"data.refreshBrowserDescriptionText\"\n        ></text-card>\n      </div>\n\n      <div class=\"flex justify-end w-full\">\n        <sa-button\n          (click)=\"connectSui()\"\n          [text]=\"data.installWalletExtensionText\"\n        ></sa-button>\n      </div>\n    </ng-template>\n  </div>\n</div>\n", styles: [".description{background-color:var(--sa-color-background-quaternary, rgb(255, 255, 255))}.openning-logo{width:72px;height:72px}\n"], dependencies: [{ kind: "directive", type: RxFor, selector: "[rxFor][rxForOf]", inputs: ["rxForOf", "rxForTemplate", "rxForStrategy", "rxForParent", "rxForPatchZone", "rxForTrackBy", "rxForRenderCallback"] }, { kind: "directive", type: RxIf, selector: "[rxIf]", inputs: ["rxIf", "rxIfStrategy", "rxIfElse", "rxIfThen", "rxIfSuspense", "rxIfComplete", "rxIfError", "rxIfContextTrigger", "rxIfNextTrigger", "rxIfSuspenseTrigger", "rxIfErrorTrigger", "rxIfCompleteTrigger", "rxIfParent", "rxIfPatchZone", "rxIfRenderCallback"] }, { kind: "pipe", type: RxPush, name: "push" }, { kind: "pipe", type: WalletIconPipe, name: "walletIcon" }, { kind: "component", type: TextCardComponent, selector: "text-card", inputs: ["header", "description"] }, { kind: "component", type: TextHeaderComponent, selector: "text-header", inputs: ["text"] }, { kind: "component", type: WalletButtonComponent, selector: "wallet-button", inputs: ["icon"] }, { kind: "component", type: ButtonComponent, selector: "sa-button", inputs: ["text", "type", "disabled"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: ConnectWalletComponent, decorators: [{
            type: Component,
            args: [{ selector: 'connect-wallet', changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [
                        RxFor,
                        RxIf,
                        RxPush,
                        WalletIconPipe,
                        TextCardComponent,
                        TextHeaderComponent,
                        WalletButtonComponent,
                        ButtonComponent,
                    ], template: "<div class=\"flex h-full\">\n  <div class=\"p-20 w-240 overflow-y-auto\">\n    <text-header [text]=\"data.connectWalletText\"></text-header>\n    <ng-container *rxIf=\"adapters | push; else dummyAdapter\">\n      <wallet-button\n        *rxFor=\"let adapter of adapters | push\"\n        [icon]=\"adapter.name\"\n        (click)=\"connectWallet(adapter)\"\n      ></wallet-button>\n    </ng-container>\n\n    <ng-template #dummyAdapter>\n      <wallet-button [icon]=\"sui\" (click)=\"registerWallet()\"></wallet-button>\n    </ng-template>\n  </div>\n  <div class=\"description flex-1 p-20 flex flex-col items-center justify-center\">\n    <ng-container *rxIf=\"!isConnecting(); else connecting\">\n      <text-header [text]=\"data.whatIsWalletText\"></text-header>\n\n      <div class=\"flex justify-center flex-1 flex-col\">\n        <text-card\n          class=\"mt-16\"\n          [header]=\"data.easyLoginHeaderText\"\n          [description]=\"data.easyLoginDescriptionText\"\n        ></text-card>\n        <text-card\n          class=\"mt-16\"\n          [header]=\"data.storeHeaderText\"\n          [description]=\"data.storeDescriptionText\"\n        ></text-card>\n      </div>\n    </ng-container>\n\n    <ng-template #connecting>\n      <div class=\"flex flex-col items-center\" *rxIf=\"(adapters | push).length; else registerWalletTmp\">\n        <img [src]=\"isConnecting() | walletIcon\" width=\"72px\"/>\n        <div class=\"text-20 text-primary mt-12\">{{ data.openingText }} {{ isConnecting() }}</div>\n        <div *rxIf=\"!error(); else errorTmp\" class=\"text-tertiary text-13\">\n          {{ data.confirmConnectText }}\n        </div>\n        <ng-template #errorTmp>\n          <div class=\"text-error text-13 text-center\">{{ error() }}</div>\n        </ng-template>\n      </div>\n    </ng-template>\n\n    <ng-template #registerWalletTmp>\n      <text-header [text]=\"data.getStartedSuiText\"></text-header>\n\n      <div class=\"flex justify-center flex-1 flex-col\">\n        <text-card\n          [header]=\"data.installExtensionHeaderText\"\n          [description]=\"data.installExtensionDescriptionText\"\n        ></text-card>\n        <text-card\n          class=\"mt-16\"\n          [header]=\"data.createOrImportHeaderText\"\n          [description]=\"data.createOrImportDescriptionText\"\n        ></text-card>\n        <text-card\n          class=\"mt-16\"\n          [header]=\"data.refreshBrowserHeaderText\"\n          [description]=\"data.refreshBrowserDescriptionText\"\n        ></text-card>\n      </div>\n\n      <div class=\"flex justify-end w-full\">\n        <sa-button\n          (click)=\"connectSui()\"\n          [text]=\"data.installWalletExtensionText\"\n        ></sa-button>\n      </div>\n    </ng-template>\n  </div>\n</div>\n", styles: [".description{background-color:var(--sa-color-background-quaternary, rgb(255, 255, 255))}.openning-logo{width:72px;height:72px}\n"] }]
        }] });

/**
 * Todo
 */
class AuthService {
    constructor() {
        this.dialog = inject(MatDialog);
    }
    /**
     * Opens a dialog for connecting a wallet and customizing its appearance.
     *
     * This method opens a dialog using the Angular Material Dialog component to facilitate
     * the process of connecting a wallet and provides options for customizing the dialog's
     * appearance and content.
     *
     * @param {OnConnectDataInterface} [data] - An optional object containing data to customize
     * the dialog's content. If not provided, default values will be used.
     *
     * @returns {Promise<MatDialogRef<ConnectWalletComponent, ConnectedWalletInterface>} - A promise that resolves to the reference of
     * the opened dialog.
     */
    async onConnect(data) {
        return this.dialog.open(ConnectWalletComponent, {
            width: '700px',
            height: '488px',
            enterAnimationDuration: '150ms',
            exitAnimationDuration: '150ms',
            panelClass: 'connect-wallet-dialog',
            backdropClass: 'connect-wallet-dialog-backdrop',
            data: {
                network: data?.network ?? SUI_MAINNET_CHAIN,
                connectWalletText: data?.connectWalletText ?? 'Connect Wallet',
                whatIsWalletText: data?.whatIsWalletText ?? 'What is Wallet',
                easyLoginHeaderText: data?.easyLoginHeaderText ?? 'Easy Login',
                easyLoginDescriptionText: data?.easyLoginDescriptionText ??
                    'No need to create new accounts and passwords for every website.' +
                        ' Just connect your wallet and get going.',
                storeHeaderText: data?.storeHeaderText ?? 'Store your Digital Assets',
                storeDescriptionText: data?.storeDescriptionText ??
                    'Send, receive, store, and display your digital assets like NFTs & coins.',
                confirmConnectText: data?.confirmConnectText ?? 'Confirm connection in the wallet...',
                openingText: data?.openingText ?? 'Opening',
                getStartedSuiText: data?.getStartedSuiText ?? 'Get Started with Sui',
                installExtensionHeaderText: data?.installExtensionHeaderText ?? 'Install the Sui extension',
                installExtensionDescriptionText: data?.installExtensionDescriptionText ??
                    'We recommend pinning the Sui Wallet to your taskbar for quicker access.',
                createOrImportHeaderText: data?.createOrImportHeaderText ?? 'Create or Import a Wallet',
                createOrImportDescriptionText: data?.createOrImportDescriptionText ??
                    'Be sure to back up your wallet using a secure method.' +
                        ' Never share your secret phrase with anyone.',
                refreshBrowserHeaderText: data?.refreshBrowserHeaderText ?? 'Refresh Your Browser',
                refreshBrowserDescriptionText: data?.refreshBrowserDescriptionText ??
                    'Once you set up your wallet, refresh this window browser to load up the extension.',
                installWalletExtensionText: data?.installWalletExtensionText ?? 'Install Wallet Extension',
            },
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: AuthService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: AuthService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: AuthService, decorators: [{
            type: Injectable
        }] });

const ELLIPSIS = '\u{2026}';
/**
 * Formats an Sui address for display by truncating it in the middle with an ellipsis.
 *
 * @param {string} address - The Sui address to format.
 * @return {string} The formatted Sui addressin format 0xd607…62eb.
 */
function formatAddress(address) {
    if (address.length <= 6) {
        return address;
    }
    const offset = address.startsWith('0x') ? 2 : 0;
    return `0x${address.slice(offset, offset + 4)}${ELLIPSIS}${address.slice(-4)}`;
}
/**
 * Formats a digest string by truncating it to the first 10 characters and appending an ellipsis.
 *
 * @param {string} digest - The digest string to format.
 * @return {string} The formatted digest string.
 */
function formatDigest(digest) {
    return `${cutDigest(digest)}${ELLIPSIS}`;
}
/**
 * Cuts a digest string by truncating it to the first 10 characters.
 *
 * @param {string} digest - The digest string to cut.
 * @return {string} The truncated digest string.
 */
function cutDigest(digest) {
    return `${digest.slice(0, 10)}`;
}
/**
 * Formats a numeric string as a decimal amount with up to 9 decimal places.
 *
 * @param {string} input - The numeric string to format.
 * @return {string} The formatted decimal amount.
 */
function formatAmount(input) {
    if (input.length < 10) {
        return `0.${input.padStart(9, '0')}`;
    }
    else {
        const wholePart = input.slice(0, -9);
        const fractionalPart = input.slice(-9);
        return `${wholePart}.${fractionalPart}`;
    }
}
/**
 * Converts a numeric price string into a SUI (SUI-wei) format string with up to 3 decimal places.
 *
 * @param {string | undefined} price - The numeric price string to convert.
 * @return {string | undefined} The converted SUI format string or undefined if the
 * input is undefined.
 */
function fromNumberToSui(price) {
    if (!price) {
        return undefined;
    }
    return returnAmountFromArray(formatAmount(price).split('.'));
}
/**
 * Removes trailing zeroes from a numeric string.
 *
 * @param {string | undefined} val - The input numeric string possibly containing trailing zeroes.
 * @return {string | undefined} A new string with trailing zeroes removed, or undefined if the
 * input is undefined or empty.
 *
 * @example
 * // Returns '123.45'
 * removeZeroes('123.4500');
 *
 * // Returns '0.5'
 * removeZeroes('0.5000');
 *
 * // Returns undefined
 * removeZeroes(undefined);
 */
function removeZeroes(val) {
    if (!val) {
        return undefined;
    }
    return returnAmountFromArray(val.split('.'));
}
/**
 * Calculate the percentage difference between an initial value and a current value.
 *
 * @param {string} init - The initial value.
 * @param {string} curr - The current value.
 * @return {string} A string representing the percentage difference, rounded to two decimal places.
 *
 * @throws {Error} If either 'init' or 'curr' is not a valid numeric string.
 *
 * @example
 * // Returns '25.00'
 * getFilled('100', '75');
 *
 * // Returns '-10.53'
 * getFilled('19.99', '22.32');
 *
 * // Throws an error because 'init' is not a valid numeric string.
 * getFilled('invalid', '50');
 */
function getFilled(init, curr) {
    return new BigNumber(init)
        .minus(new BigNumber(curr))
        .dividedBy(new BigNumber(init))
        .multipliedBy(100)
        .toFixed(2);
}
/**
 * Formats a SUI (Sui Generis Unit) value to a whole SUI string, removing leading and trailing
 * zeros.
 *
 * @param {string} sui - The SUI value to format.
 * @return {string} The formatted whole SUI string.
 * @example
 * // Returns '1.123'
 * formatToWholeSui('1123000000');
 */
function formatToWholeSui(sui) {
    return removeZeroes(fromNumberToSui(sui)) ?? '';
}
/**
 * Get the balance of a specific asset in a list of CoinBalance objects.
 *
 * @param {CoinBalance[]} allTokens - An array of CoinBalance objects containing asset balances.
 * @param {string} asset - The asset for which you want to retrieve the balance.
 * @return {string} The total balance of the specified asset, or an empty string if not found.
 */
function getTokenBalance(allTokens, asset) {
    return allTokens.find((c) => c.coinType === asset)?.totalBalance ?? '';
}
/**
 * Formats an array of string values as a single string with up to three decimal places.
 *
 * This function takes an array of string values representing a numerical amount,
 * and it formats them as a single string with up to three decimal places. If the array contains
 * two elements, it joins them with a dot (.) separator, keeping up to three decimal places.
 *  If the array contains only one element, it  returns that element as is.
 *
 * @param {string[]} amountArr - An array of string values representing a numerical amount.
 * @return {string} The formatted numerical amount as a string.
 */
function returnAmountFromArray(amountArr) {
    return amountArr.length > 1
        ? [amountArr[0], amountArr[1].substring(0, 3)].join('.')
        : amountArr[0];
}
/**
 * Converts a price value from SUI (Subunit) to Wei (the smallest unit of SUI).
 *
 * This function takes a price value as a string in SUI (Subunit) format and converts
 * it to Wei format.
 * SUI is a format where the price can have up to 9 decimal places represented as a string.
 * Wei is the smallest unit of SUI, and it does not use decimal places.
 *
 * @param {string} price - The price value in SUI format (e.g., "123.456789123").
 * @return {string} The price value converted to Wei format as a string.
 */
function fromSuiToWei(price) {
    const priceRaw = (price ?? '0').split('.');
    return priceRaw.length > 1
        ? [priceRaw[0], priceRaw[1].padEnd(9, '0')].join('')
        : new BigNumber(1000000000).multipliedBy(priceRaw[0]).toString().split('.')[0];
}
/**
 * Calculate and retrieve the percentage value of a given amount.
 *
 * @param {string | undefined} amount - The input amount as a string.
 * @param {string | undefined} percent - The percentage to be applied as a string.
 * @return {string} The calculated percentage value as a string.
 */
function getPercentFromAMount(amount, percent) {
    if (!amount || !percent) {
        return '';
    }
    return new BigNumber(amount).div(100).multipliedBy(percent).toString().split('.')[0];
}
/**
 * Calculate the result of multiplying a percentage by an amount and dividing by 100.
 *
 * @param {string | undefined | null} total - The total value.
 * @param {number | undefined | null} percent - The percentage to apply.
 * @param {number | undefined | null} amount - The amount to be multiplied by the percentage.
 * @return {string} The result of multiplying the percentage by the amount and dividing by 100
 * as a string.
 * If any of the input values (total, percent, or amount) are falsy, an empty string is returned.
 */
function getPercenMulByAmount(total, percent, amount) {
    if (!total || !amount || !percent) {
        return '';
    }
    return new BigNumber(total)
        .div(100)
        .multipliedBy(percent)
        .multipliedBy(amount)
        .toString()
        .split('.')[0];
}
/**
 * Calculate the result of dividing an amount by 100, then multiplying by a percentage.
 *
 * @param {string | undefined | null} total - The total value.
 * @param {number | undefined | null} percent - The percentage to apply.
 * @param {string | undefined | null} amount - The amount to be divided and then multiplied by
 * the percentage.
 * @return {string} The result of dividing the amount by 100, multiplying by the percentage,
 * and returning it as a string.
 * If any of the input values (total, percent, or amount) are falsy, an empty string is returned.
 */
function getPercenDivByAmount(total, percent, amount) {
    if (!total || !amount || !percent) {
        return '';
    }
    return new BigNumber(total).div(amount).div(100).multipliedBy(percent).toString().split('.')[0];
}

/**
 * The Account Wallet Button Component.
 */
class AccountWalletButtonComponent {
    constructor() {
        this.disconnect = new EventEmitter();
    }
    /**
     * Retrieves a formatted representation of the account.
     *
     * @public
     * @getter
     * @type {string}
     * @return {string} A formatted representation of the account, or an empty string if no
     * account is available.
     */
    get account() {
        return formatAddress(this.walletAccount ?? '');
    }
    /**
     * Handles the disconnect event and emits it to subscribers.
     *
     * This method is responsible for emitting the disconnect event to inform
     * subscribers about the disconnection.
     *
     * @emits disconnect - An event indicating a disconnection.
     *
     * @returns {void}
     */
    onDisconnect() {
        this.disconnect.emit();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: AccountWalletButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.10", type: AccountWalletButtonComponent, isStandalone: true, selector: "account-wallet-button", inputs: { walletName: "walletName", walletAccount: "walletAccount", disconnectText: "disconnectText" }, outputs: { disconnect: "disconnect" }, ngImport: i0, template: "<div\n  class=\"flex items-center py-8 px-16 connected-button mx-12 cursor-pointer\"\n  [matMenuTriggerFor]=\"menu\"\n>\n  <img [src]=\"walletName | walletIcon\" width=\"24\" height=\"24\" />\n  <div class=\"ml-4 text-14 text-primary\">{{ account }}</div>\n</div>\n\n<mat-menu class=\"account-dropdown\" #menu=\"matMenu\">\n  <div class=\"flex justify-start px-16 h-full\" (click)=\"$event.stopPropagation()\">\n    <button mat-button (click)=\"onDisconnect()\"><span class=\"text-primary text-13\">{{disconnectText}}</span></button>\n  </div>\n</mat-menu>\n", styles: [".connected-button{background-color:var(--sa-color-background-tertiary, rgb(247, 248, 248));border-radius:12px;border:1px solid var(--sa-color-background-tertiary, rgb(247, 248, 248))}.connected-button:hover{background-color:var(--sa-color-background-quaternary, rgb(255, 255, 255))}\n"], dependencies: [{ kind: "ngmodule", type: MatMenuModule }, { kind: "component", type: i1.MatMenu, selector: "mat-menu", exportAs: ["matMenu"] }, { kind: "directive", type: i1.MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", exportAs: ["matMenuTrigger"] }, { kind: "pipe", type: WalletIconPipe, name: "walletIcon" }, { kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i2.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: AccountWalletButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'account-wallet-button', standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, imports: [MatMenuModule, WalletIconPipe, MatButtonModule], template: "<div\n  class=\"flex items-center py-8 px-16 connected-button mx-12 cursor-pointer\"\n  [matMenuTriggerFor]=\"menu\"\n>\n  <img [src]=\"walletName | walletIcon\" width=\"24\" height=\"24\" />\n  <div class=\"ml-4 text-14 text-primary\">{{ account }}</div>\n</div>\n\n<mat-menu class=\"account-dropdown\" #menu=\"matMenu\">\n  <div class=\"flex justify-start px-16 h-full\" (click)=\"$event.stopPropagation()\">\n    <button mat-button (click)=\"onDisconnect()\"><span class=\"text-primary text-13\">{{disconnectText}}</span></button>\n  </div>\n</mat-menu>\n", styles: [".connected-button{background-color:var(--sa-color-background-tertiary, rgb(247, 248, 248));border-radius:12px;border:1px solid var(--sa-color-background-tertiary, rgb(247, 248, 248))}.connected-button:hover{background-color:var(--sa-color-background-quaternary, rgb(255, 255, 255))}\n"] }]
        }], propDecorators: { walletName: [{
                type: Input
            }], walletAccount: [{
                type: Input
            }], disconnectText: [{
                type: Input
            }], disconnect: [{
                type: Output
            }] } });

const WALLET = '@sui-angular/wallet';
/**
 * The Connect Button Container Store
 */
class ConnectButtonContainerStore extends ComponentStore {
    /**
     * Constructs an instance of a component.
     *
     * Initializes the component's properties, including its connection state and wallet information.
     *
     * @constructor
     */
    constructor() {
        const walletStr = localStorage.getItem(WALLET);
        super({
            connecting: false,
            connected: false,
            wallet: walletStr
                ? JSON.parse(walletStr)
                : undefined,
            error: undefined,
        });
        this.selectAccount = this.selectSignal((state) => state.wallet?.account);
        this.selectWalletName = this.selectSignal((state) => state.wallet?.name);
        this.updateWallet = this.updater((state, wallet) => {
            localStorage.setItem(WALLET, wallet ? JSON.stringify(wallet) : '');
            return {
                ...state,
                wallet,
            };
        });
        this.connectWallet = this.effect((event$) => {
            return event$.pipe(tap((event) => {
                this.updateWallet(event);
            }));
        });
        this.clearWallet = this.effect((event$) => {
            return event$.pipe(tap(() => {
                this.updateWallet(undefined);
            }));
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: ConnectButtonContainerStore, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: ConnectButtonContainerStore }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: ConnectButtonContainerStore, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return []; } });

/**
 * The Connect Button Container Component
 */
class ConnectButtonContainerComponent {
    constructor() {
        this.authService = inject(AuthService);
        this.compStore = inject(ConnectButtonContainerStore);
        this.walletStandardService = inject(WalletStandardService);
        this.destroyRef = inject(DestroyRef);
        this._connected = false;
        this.walletName = this.compStore.selectWalletName;
        this.walletAccount = this.compStore.selectAccount;
        this.connected = new EventEmitter();
    }
    /**
     * Retrieves the text for the connect button.
     *
     * This getter returns the text to be displayed on the connect button, using the
     * value from the `translations` property if available, or a default value of
     * 'Connect' if no translation is provided.
     *
     * @returns {string} The text for the connect button.
     */
    get connectButtonText() {
        return this.translations?.connectButtonText ?? 'Connect';
    }
    /**
     * Retrieves the text for the disconnect button.
     *
     * This getter returns the text to be displayed on the disconnect button, using
     * the value from the `translations` property if available, or a default value of
     * 'Disconnect' if no translation is provided.
     *
     * @returns {string} The text for the disconnect button.
     */
    get disconnectText() {
        return this.translations?.disconnectText ?? 'Disconnect';
    }
    /**
     * Angular lifecycle hook invoked when the component is initialized.
     *
     * This method is automatically called by Angular when the component is initialized.
     * It checks for the presence of a wallet name and account, and if they are both available,
     * it attempts to connect to the corresponding wallet using the provided adapters.
     * Upon a successful connection, it emits a 'connected' event with the account and wallet name.
     * If the connection fails, it clears the wallet information in the component's store.
     *
     * @fires connected - Event emitted upon a successful wallet connection.
     *
     * @throws {Error} If a wallet connection cannot be established.
     */
    ngOnInit() {
        const walletName = this.walletName();
        const walletAccount = this.walletAccount();
        this.walletStandardService.availableWalletAdapters$
            .pipe(filter(() => !!walletName && !!walletAccount), map((wallets) => wallets.find((adapter) => adapter.name === walletName)), filter((walletAdapter) => !!walletAdapter && has$1(walletAdapter?.features, 'standard:connect')), map((walletAdapter) => walletAdapter.features['standard:connect']), filter(() => !this._connected), exhaustMap((feature) => feature.connect()), tap(() => {
            this.connected.emit({
                account: walletAccount,
                name: walletName,
            });
            this._connected = true;
        }), catchError(() => {
            this._connected = false;
            this.compStore.clearWallet();
            return EMPTY;
        }), takeUntilDestroyed(this.destroyRef))
            .subscribe();
    }
    /**
     * Opens a modal dialog for connecting a wallet.
     *
     * This method triggers the authentication service to open a modal dialog for connecting
     * a wallet with the specified network and localization settings. Upon successful
     * completion of the modal, it emits a 'connected' event and updates the component store
     * with the connected wallet information.
     *
     * @returns {Promise<void>} A promise that resolves when the modal dialog is closed.
     *
     * @fires connected - Event emitted upon successful wallet connection.
     *
     * @param {object} [translations] - An optional object containing localized text for
     * various UI elements in the modal dialog.
     * @param {string} translations.connectWalletText - Text for the 'Connect Wallet' button.
     * @param {string} translations.whatIsWalletText - Text for explaining what a wallet is.
     * @param {string} translations.easyLoginHeaderText - Header text for easy login information.
     * @param {string} translations.easyLoginDescriptionText - Description text for easy login information.
     * @param {string} translations.storeHeaderText - Header text for explaining wallet storage.
     * @param {string} translations.storeDescriptionText - Description text for wallet storage information.
     * @param {string} translations.confirmConnectText - Text for confirming the wallet connection.
     * @param {string} translations.openingText - Text displayed while the wallet connection is being established.
     * @param {string} translations.getStartedSuiText - Text for getting started with SUI.
     * @param {string} translations.installExtensionHeaderText - Header text for installing the wallet extension.
     * @param {string} translations.installExtensionDescriptionText - Description text for installing the wallet extension.
     * @param {string} translations.createOrImportHeaderText - Header text for creating or importing a wallet.
     * @param {string} translations.createOrImportDescriptionText - Description text for creating or importing a wallet.
     * @param {string} translations.refreshBrowserHeaderText - Header text for refreshing the browser.
     * @param {string} translations.refreshBrowserDescriptionText - Description text for refreshing the browser.
     * @param {string} translations.installWalletExtensionText - Text for installing the wallet extension.
     */
    async openConnectModal() {
        const dialogRef = await this.authService.onConnect({
            network: this.translations?.network,
            connectWalletText: this.translations?.connectWalletText,
            whatIsWalletText: this.translations?.whatIsWalletText,
            easyLoginHeaderText: this.translations?.easyLoginHeaderText,
            easyLoginDescriptionText: this.translations?.easyLoginDescriptionText,
            storeHeaderText: this.translations?.storeHeaderText,
            storeDescriptionText: this.translations?.storeDescriptionText,
            confirmConnectText: this.translations?.confirmConnectText,
            openingText: this.translations?.openingText,
            getStartedSuiText: this.translations?.getStartedSuiText,
            installExtensionHeaderText: this.translations?.installExtensionHeaderText,
            installExtensionDescriptionText: this.translations?.installExtensionDescriptionText,
            createOrImportHeaderText: this.translations?.createOrImportHeaderText,
            createOrImportDescriptionText: this.translations?.createOrImportDescriptionText,
            refreshBrowserHeaderText: this.translations?.refreshBrowserHeaderText,
            refreshBrowserDescriptionText: this.translations?.refreshBrowserDescriptionText,
            installWalletExtensionText: this.translations?.installWalletExtensionText,
        });
        dialogRef.afterClosed().subscribe((data) => {
            if (data) {
                this.connected.emit({
                    account: data.account,
                    name: data.name,
                });
                this.compStore.connectWallet(data);
            }
        });
    }
    /**
     * Clears wallet information to disconnect from the wallet.
     *
     * This method is responsible for disconnecting from the wallet by clearing
     * wallet-related information in the component store.
     *
     * @returns {void} - This method does not return a value.
     */
    onDisconnect() {
        this.compStore.clearWallet();
        this.connected.emit(undefined);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: ConnectButtonContainerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.10", type: ConnectButtonContainerComponent, isStandalone: true, selector: "connect-button-container", inputs: { translations: "translations" }, outputs: { connected: "connected" }, providers: [ConnectButtonContainerStore], ngImport: i0, template: "<sa-button\n  class=\"block mx-12\"\n  *rxIf=\"!walletName(); else walletButton\"\n  [text]=\"connectButtonText\"\n  (click)=\"openConnectModal()\"\n></sa-button>\n\n<ng-template #walletButton>\n  <account-wallet-button\n    [walletName]=\"walletName()\"\n    [walletAccount]=\"walletAccount()\"\n    [disconnectText]=\"disconnectText\"\n    (disconnect)=\"onDisconnect()\"\n  ></account-wallet-button>\n</ng-template>\n", styles: [":host{display:block;width:-moz-fit-content;width:fit-content}\n"], dependencies: [{ kind: "component", type: ButtonComponent, selector: "sa-button", inputs: ["text", "type", "disabled"] }, { kind: "component", type: AccountWalletButtonComponent, selector: "account-wallet-button", inputs: ["walletName", "walletAccount", "disconnectText"], outputs: ["disconnect"] }, { kind: "directive", type: RxIf, selector: "[rxIf]", inputs: ["rxIf", "rxIfStrategy", "rxIfElse", "rxIfThen", "rxIfSuspense", "rxIfComplete", "rxIfError", "rxIfContextTrigger", "rxIfNextTrigger", "rxIfSuspenseTrigger", "rxIfErrorTrigger", "rxIfCompleteTrigger", "rxIfParent", "rxIfPatchZone", "rxIfRenderCallback"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: ConnectButtonContainerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'connect-button-container', standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, imports: [ButtonComponent, AccountWalletButtonComponent, RxIf], providers: [ConnectButtonContainerStore], template: "<sa-button\n  class=\"block mx-12\"\n  *rxIf=\"!walletName(); else walletButton\"\n  [text]=\"connectButtonText\"\n  (click)=\"openConnectModal()\"\n></sa-button>\n\n<ng-template #walletButton>\n  <account-wallet-button\n    [walletName]=\"walletName()\"\n    [walletAccount]=\"walletAccount()\"\n    [disconnectText]=\"disconnectText\"\n    (disconnect)=\"onDisconnect()\"\n  ></account-wallet-button>\n</ng-template>\n", styles: [":host{display:block;width:-moz-fit-content;width:fit-content}\n"] }]
        }], propDecorators: { translations: [{
                type: Input
            }], connected: [{
                type: Output
            }] } });

class SuiAngularCoreModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: SuiAngularCoreModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.10", ngImport: i0, type: SuiAngularCoreModule, imports: [ConnectButtonContainerComponent,
            AccountWalletButtonComponent,
            ButtonComponent,
            ConnectWalletComponent,
            TextCardComponent,
            TextHeaderComponent,
            WalletButtonComponent,
            MatDialogModule], exports: [ConnectButtonContainerComponent,
            AccountWalletButtonComponent,
            ButtonComponent,
            ConnectWalletComponent,
            TextCardComponent,
            TextHeaderComponent,
            WalletButtonComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: SuiAngularCoreModule, providers: [AuthService, WalletStandardService], imports: [ConnectButtonContainerComponent,
            AccountWalletButtonComponent,
            MatDialogModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.10", ngImport: i0, type: SuiAngularCoreModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        ConnectButtonContainerComponent,
                        AccountWalletButtonComponent,
                        ButtonComponent,
                        ConnectWalletComponent,
                        TextCardComponent,
                        TextHeaderComponent,
                        WalletButtonComponent,
                        MatDialogModule,
                    ],
                    providers: [AuthService, WalletStandardService],
                    exports: [
                        ConnectButtonContainerComponent,
                        AccountWalletButtonComponent,
                        ButtonComponent,
                        ConnectWalletComponent,
                        TextCardComponent,
                        TextHeaderComponent,
                        WalletButtonComponent,
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AccountWalletButtonComponent, AuthService, ButtonComponent, ConnectButtonContainerComponent, ConnectButtonContainerStore, ConnectWalletComponent, SUI_CHAINS, SUI_DEVNET_CHAIN, SUI_LOCALNET_CHAIN, SUI_MAINNET_CHAIN, SUI_TESTNET_CHAIN, SuiAngularCoreModule, TextCardComponent, TextHeaderComponent, WALLET, WalletButtonComponent, WalletIconEnum, WalletIconPipe, cutDigest, formatAddress, formatAmount, formatDigest, formatToWholeSui, fromNumberToSui, fromSuiToWei, getFilled, getPercenDivByAmount, getPercenMulByAmount, getPercentFromAMount, getTokenBalance, removeZeroes, returnAmountFromArray };
//# sourceMappingURL=sui-angular-core.mjs.map
