import { EventEmitter, OnInit } from '@angular/core';
import { OnConnectDataInterface } from '../../services';
import { ConnectedWalletInterface } from '../../models';
import * as i0 from "@angular/core";
export declare class ConnectButtonContainerComponent implements OnInit {
    private readonly authService;
    private readonly compStore;
    private readonly walletStandardService;
    private readonly destroyRef;
    private _connected;
    readonly walletName: import("@angular/core").Signal<string | undefined>;
    readonly walletAccount: import("@angular/core").Signal<string | undefined>;
    translations?: OnConnectDataInterface;
    connected: EventEmitter<ConnectedWalletInterface>;
    /**
     * Retrieves the text for the connect button.
     *
     * This getter returns the text to be displayed on the connect button, using the
     * value from the `translations` property if available, or a default value of
     * 'Connect' if no translation is provided.
     *
     * @returns {string} The text for the connect button.
     */
    get connectButtonText(): string;
    /**
     * Retrieves the text for the disconnect button.
     *
     * This getter returns the text to be displayed on the disconnect button, using
     * the value from the `translations` property if available, or a default value of
     * 'Disconnect' if no translation is provided.
     *
     * @returns {string} The text for the disconnect button.
     */
    get disconnectText(): string;
    /**
     * Angular lifecycle hook invoked when the component is initialized.
     *
     * This method is automatically called by Angular when the component is initialized.
     * It checks for the presence of a wallet name and account, and if they are both available,
     * it attempts to connect to the corresponding wallet using the provided adapters.
     * Upon a successful connection, it emits a 'connected' event with the account and wallet name.
     * If the connection fails, it clears the wallet information in the component's store.
     *
     * @fires connected - Event emitted upon a successful wallet connection.
     *
     * @throws {Error} If a wallet connection cannot be established.
     */
    ngOnInit(): void;
    /**
     * Opens a modal dialog for connecting a wallet.
     *
     * This method triggers the authentication service to open a modal dialog for connecting
     * a wallet with the specified network and localization settings. Upon successful
     * completion of the modal, it emits a 'connected' event and updates the component store
     * with the connected wallet information.
     *
     * @returns {Promise<void>} A promise that resolves when the modal dialog is closed.
     *
     * @fires connected - Event emitted upon successful wallet connection.
     *
     * @param {object} [translations] - An optional object containing localized text for
     * various UI elements in the modal dialog.
     * @param {string} translations.connectWalletText - Text for the 'Connect Wallet' button.
     * @param {string} translations.whatIsWalletText - Text for explaining what a wallet is.
     * @param {string} translations.easyLoginHeaderText - Header text for easy login information.
     * @param {string} translations.easyLoginDescriptionText - Description text for easy login information.
     * @param {string} translations.storeHeaderText - Header text for explaining wallet storage.
     * @param {string} translations.storeDescriptionText - Description text for wallet storage information.
     * @param {string} translations.confirmConnectText - Text for confirming the wallet connection.
     * @param {string} translations.openingText - Text displayed while the wallet connection is being established.
     * @param {string} translations.getStartedSuiText - Text for getting started with SUI.
     * @param {string} translations.installExtensionHeaderText - Header text for installing the wallet extension.
     * @param {string} translations.installExtensionDescriptionText - Description text for installing the wallet extension.
     * @param {string} translations.createOrImportHeaderText - Header text for creating or importing a wallet.
     * @param {string} translations.createOrImportDescriptionText - Description text for creating or importing a wallet.
     * @param {string} translations.refreshBrowserHeaderText - Header text for refreshing the browser.
     * @param {string} translations.refreshBrowserDescriptionText - Description text for refreshing the browser.
     * @param {string} translations.installWalletExtensionText - Text for installing the wallet extension.
     */
    openConnectModal(): Promise<void>;
    /**
     * Clears wallet information to disconnect from the wallet.
     *
     * This method is responsible for disconnecting from the wallet by clearing
     * wallet-related information in the component store.
     *
     * @returns {void} - This method does not return a value.
     */
    onDisconnect(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ConnectButtonContainerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ConnectButtonContainerComponent, "connect-button-container", never, { "translations": { "alias": "translations"; "required": false; }; }, { "connected": "connected"; }, never, never, true, never>;
}
